@@ -1001,14 +1001,6 @@ _gnutls_recv_handshake_header (gnutls_session_t session,
 
       *recv_type = session->internals.handshake_header_buffer.recv_type;
 
-      if (*recv_type != type)
-	{
-	  gnutls_assert ();
-	  _gnutls_handshake_log
-	    ("HSK[%x]: Handshake type mismatch (under attack?)\n", session);
-	  return GNUTLS_E_UNEXPECTED_HANDSHAKE_PACKET;
-	}
-
       return session->internals.handshake_header_buffer.packet_length;
     }
 
@@ -2051,7 +2043,7 @@ _gnutls_recv_hello (gnutls_session_t session, opaque * data, int datalen)
  */
 
 /**
-  * gnutls_rehandshake - This function will renegotiate security parameters
+  * gnutls_rehandshake - renegotiate security parameters
   * @session: is a #gnutls_session_t structure.
   *
   * This function will renegotiate security parameters with the
@@ -2961,7 +2953,7 @@ _gnutls_remove_unwanted_ciphersuites (gnutls_session_t session,
 }
 
 /**
-  * gnutls_handshake_set_max_packet_length - This function will set the maximum length of a handshake message
+  * gnutls_handshake_set_max_packet_length - set the maximum length of a handshake message
   * @session: is a #gnutls_session_t structure.
   * @max: is the maximum number.
   *
