@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001, 2002, 2003, 2004, 2005 Free Software Foundation
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2008 Free Software Foundation
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -422,7 +422,8 @@ gnutls_srp_free_client_credentials (gnutls_srp_client_credentials_t sc)
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to allocate it.
   *
-  * Returns 0 on success.
+  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, or an
+  *   error code.
   **/
 int
 gnutls_srp_allocate_client_credentials (gnutls_srp_client_credentials_t * sc)
@@ -441,11 +442,14 @@ gnutls_srp_allocate_client_credentials (gnutls_srp_client_credentials_t * sc)
   * @username: is the user's userid
   * @password: is the user's password
   *
-  * This function sets the username and password, in a gnutls_srp_client_credentials_t structure.
-  * Those will be used in SRP authentication. @username and @password should be ASCII
-  * strings or UTF-8 strings prepared using the "SASLprep" profile of "stringprep".
+  * This function sets the username and password, in a
+  * #gnutls_srp_client_credentials_t structure.  Those will be used in
+  * SRP authentication.  @username and @password should be ASCII
+  * strings or UTF-8 strings prepared using the "SASLprep" profile of
+  * "stringprep".
   *
-  * Returns 0 on success.
+  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, or an
+  *   error code.
   **/
 int
 gnutls_srp_set_client_credentials (gnutls_srp_client_credentials_t res,
@@ -493,10 +497,11 @@ gnutls_srp_free_server_credentials (gnutls_srp_server_credentials_t sc)
   * gnutls_srp_allocate_server_credentials - Used to allocate an gnutls_srp_server_credentials_t structure
   * @sc: is a pointer to an #gnutls_srp_server_credentials_t structure.
   *
-  * This structure is complex enough to manipulate directly thus
-  * this helper function is provided in order to allocate it.
-  * 
-  * Returns 0 on success.
+  * This structure is complex enough to manipulate directly thus this
+  * helper function is provided in order to allocate it.
+  *
+  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, or an
+  *   error code.
   **/
 int
 gnutls_srp_allocate_server_credentials (gnutls_srp_server_credentials_t * sc)
@@ -515,11 +520,13 @@ gnutls_srp_allocate_server_credentials (gnutls_srp_server_credentials_t * sc)
   * @password_file: is the SRP password file (tpasswd)
   * @password_conf_file: is the SRP password conf file (tpasswd.conf)
   *
-  * This function sets the password files, in a gnutls_srp_server_credentials_t structure.
-  * Those password files hold usernames and verifiers and will be used for SRP authentication.
-  *
-  * Returns 0 on success.
+  * This function sets the password files, in a
+  * #gnutls_srp_server_credentials_t structure.  Those password files
+  * hold usernames and verifiers and will be used for SRP
+  * authentication.
   *
+  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, or an
+  *   error code.
   **/
 int
 gnutls_srp_set_server_credentials_file (gnutls_srp_server_credentials_t
@@ -611,42 +618,42 @@ gnutls_srp_set_server_credentials_function (gnutls_srp_server_credentials_t
   *
   * This function can be used to set a callback to retrieve the username and
   * password for client SRP authentication.
-  * The callback's function form is:
-  * int (*callback)(gnutls_session_t, char** username,
-  *  char** password);
   *
-  * The @username and @password must be allocated using gnutls_malloc().
-  * @username and @password should be ASCII strings or UTF-8 strings 
-  * prepared using the "SASLprep" profile of "stringprep".
+  * The callback's function form is:
+  *
+  * int (*callback)(gnutls_session_t, char** username, char**password);
+  *
+  * The @username and @password must be allocated using
+  * gnutls_malloc().  @username and @password should be ASCII strings
+  * or UTF-8 strings prepared using the "SASLprep" profile of
+  * "stringprep".
   *
   * The callback function will be called once per handshake before the
   * initial hello message is sent.
-  * 
+  *
   * The callback should not return a negative error code the second
   * time called, since the handshake procedure will be aborted.
   *
   * The callback function should return 0 on success.
   * -1 indicates an error.
-  *
   **/
 void
-gnutls_srp_set_client_credentials_function (gnutls_srp_client_credentials_t
-					    cred,
-					    gnutls_srp_client_credentials_function
-					    * func)
+gnutls_srp_set_client_credentials_function (gnutls_srp_client_credentials_t cred,
+					    gnutls_srp_client_credentials_function * func)
 {
   cred->get_function = func;
 }
 
 
 /**
-  * gnutls_srp_server_get_username - This function returns the username of the peer
+  * gnutls_srp_server_get_username - return the username of the peer
   * @session: is a gnutls session
   *
-  * This function will return the username of the peer. This should only be
-  * called in case of SRP authentication and in case of a server.
-  * Returns NULL in case of an error.
+  * This function will return the username of the peer.  This should
+  * only be called in case of SRP authentication and in case of a
+  * server.  Returns NULL in case of an error.
   *
+  * Returns: SRP username of the peer, or NULL in case of error.
   **/
 const char *
 gnutls_srp_server_get_username (gnutls_session_t session)
@@ -670,13 +677,17 @@ gnutls_srp_server_get_username (gnutls_session_t session)
   * @prime: is the group's prime
   * @res: where the verifier will be stored.
   *
-  * This function will create an SRP verifier, as specified in RFC2945.
-  * The @prime and @generator should be one of the static parameters defined
-  * in gnutls/extra.h or may be generated using the GCRYPT functions
-  * gcry_prime_generate() and gcry_prime_group_generator().
-  * The verifier will be allocated with @malloc and will be stored in @res using 
-  * binary format.
+  * This function will create an SRP verifier, as specified in
+  * RFC2945.  The @prime and @generator should be one of the static
+  * parameters defined in gnutls/extra.h or may be generated using the
+  * libgcrypt functions gcry_prime_generate() and
+  * gcry_prime_group_generator().
   *
+  * The verifier will be allocated with @malloc and will be stored in
+  * @res using binary format.
+  *
+  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, or an
+  *   error code.
   **/
 int
 gnutls_srp_verifier (const char *username, const char *password,
