@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005, 2007 Free Software Foundation
+ * Copyright (C) 2003, 2004, 2005, 2007, 2008 Free Software Foundation
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -33,12 +33,7 @@
 #include <common.h>
 #include <gnutls_x509.h>
 #include <x509_b64.h>
-#include <x509.h>
-#include <dn.h>
-#include <pkcs12.h>
-#include <privkey.h>
-#include <extensions.h>
-#include <mpi.h>
+#include "x509_int.h"
 #include <gnutls_algorithms.h>
 #include <gnutls_num.h>
 #include <gc.h>
